@@ -99,7 +99,7 @@ class SuperUserBackend(CognitoUserBackend):
         self,
         request: HttpRequest,
         user: AbstractBaseUser,
-        created: bool = False,
+        created: bool = True,
         **kwargs: Any,
     ) -> AbstractBaseUser:
         """
@@ -107,11 +107,12 @@ class SuperUserBackend(CognitoUserBackend):
 
         By default, return the user unmodified.
         """
+
         if created:
             user.set_unusable_password()
             user.email = self.cognito_jwt["email"]  # type: ignore [attr-defined]
-            user.first_name = self.cognito_jwt.get("given_name")  # type: ignore
-            user.last_name = self.cognito_jwt.get("family_name")  # type: ignore
+            user.first_name = self.cognito_jwt.get("given_name") or ""  # type: ignore
+            user.last_name = self.cognito_jwt.get("family_name") or ""  # type: ignore
             user.is_superuser = True  # type: ignore [attr-defined]
             user.is_staff = True  # type: ignore [attr-defined]
             user.save()
